<?php
class Sleeky_Int {

	/**
	 * preloader compatibility.
	 */
	public static function sleeky_preloader() {
		$preloader_on_off = sleeky_get_options( 'preloader_on_off' );

		$header_style_meta = get_post_meta( get_the_ID(), 'sleeky_core_header_style', true );
		if ( $header_style_meta ) {
			$header_style = $header_style_meta;
		} else {
			$header_style = sleeky_get_options( 'header_style' );
		}
		$preloader_style = '';
		if( $header_style == '3' || $header_style == '4') {
			$preloader_style = 'style-two';
		}

		if ( $preloader_on_off ) : ?>
			<!-- preloader -->
			<div class="loader-wrap">
				<div class="preloader">
					<div class="preloader-close">x</div>
					<div id="handle-preloader" class="handle-preloader <?php echo esc_attr($preloader_style); ?>">
						<div class="animation-preloader">
							<div class="spinner"></div>
							<div class="txt-loading">
								<span data-text-preloader="s" class="letters-loading">
									s
								</span>
								<span data-text-preloader="l" class="letters-loading">
									l
								</span>
								<span data-text-preloader="e" class="letters-loading">
									e
								</span>
								<span data-text-preloader="e" class="letters-loading">
									e
								</span>
								<span data-text-preloader="k" class="letters-loading">
									k
								</span>
								<span data-text-preloader="y" class="letters-loading">
									y
								</span>
							</div>
						</div>  
					</div>
				</div>
			</div>
        <!-- preloader end -->
			<?php
		endif;
	}
	/**
	 * back to top compatibility.
	 */
	public static function sleeky_back_to_top() {
		$back_to_top_on_off = sleeky_get_options( 'back_to_top_on_off' );
		if ( $back_to_top_on_off == '1' ) :
			?>
			 <!--Scroll to top-->
			 <button class="scroll-top scroll-to-target" data-target="html">
				<span class="fal fa-angle-up"></span>
			</button>
			<?php
			endif;
		}

	/**
	 * header logo compatibility.
	 */
	public static function sleeky_header_logo() {

		$sleeky_core_header_logo = get_post_meta(get_the_ID(), 'sleeky_core_header_logo', array('size' => 'full'));
		if (!empty($sleeky_core_header_logo)) {
		?>
			<a href="<?php echo esc_url(home_url('/')); ?>">
				<img src="<?php echo esc_url(wp_get_attachment_url($sleeky_core_header_logo)); ?>" alt="<?php esc_attr_e('Logo', 'sleeky') ?>">
			</a>
			<?php
		} else{
			if ( has_custom_logo() ) {
				the_custom_logo();
			} elseif ( ! has_custom_logo() ) {
				?>
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
					<img src="<?php echo esc_url( SLEEKY_IMG_URL . 'logo-3.svg' ); ?>" alt="<?php esc_attr_e( 'Logo', 'sleeky' ); ?>">
				</a> 
				<?php
			}
		}
	}

	/**
	 * header menu compatibility.
	 */
	public static function sleeky_header_menu() {

		if ( has_nav_menu( 'primary' ) ) {
			wp_nav_menu(
				array(
					'theme_location' => 'primary',
					'depth'          => 3, // 1 = no dropdowns, 2 = with dropdowns.
					'menu_class'     => 'navigation clearfix',
					'container'      => 'ul',
				)
			);
		} else {
			wp_nav_menu(
				array(
					'depth'      => 3, // 1 = no dropdowns, 2 = with dropdowns.
					'menu_class' => 'navigation clearfix',
					'container'  => 'ul',
				)
			);
		}
	}

	/**
	 * All header and breadcrumb.
	*/
	public static function sleeky_breadcrumb() {
		$breadcrumb_title = 'sleeky';
		$breadcrumb_extra_class = '';
		$breadcrumb_class = 'breadcrumb_no_bg';
		if ( is_front_page() && is_home() ) :
			$breadcrumb_title = ''; // deafult blog
			$breadcrumb_class = 'deafult-home-breadcrumb';
		elseif ( is_front_page() && ! is_home() ) :
			$breadcrumb_title = ''; // custom home or deafult
			$breadcrumb_class = 'custom-home-breadcrumb';
		elseif ( is_home() ) :
			$blog_breadcrumb_switch = sleeky_get_options( 'blog_breadcrumb_switch' );
			if ( $blog_breadcrumb_switch == '1' ) :
				$sleeky_page_title  = get_post_meta( get_the_ID(), 'sleeky_core_breadcrumb_title', true );
				if($sleeky_page_title){
					$blog_breadcrumb_content = $sleeky_page_title;
				} else {
					$blog_breadcrumb_content = sleeky_get_options( 'blog_breadcrumb_content' );
				}
				
				$breadcrumb_title = $blog_breadcrumb_content;
			else :
				$breadcrumb_title = '';
			endif;
			$breadcrumb_class = 'blog-breadcrumb';
		elseif ( is_archive() ) :

			$breadcrumb_class = 'blog-breadcrumb';
			$breadcrumb_title = get_the_archive_title();

		elseif ( is_single() ) :
			if ( get_post_type( get_the_ID() ) == 'post' ) :
				$blog_single_breadcrumb_switch = sleeky_get_options( 'blog_single_breadcrumb_switch' );
				if ( $blog_single_breadcrumb_switch == '1' ) :
					// redux
					$blog_single_breadcrumb_content = sleeky_get_options( 'blog_single_breadcrumb_content' );
					$breadcrumb_title               = $blog_single_breadcrumb_content;
					$breadcrumb_class               = 'blogsingle-breadcrumb style-two';
				else :
					$breadcrumb_title = get_the_title();
				endif;
			else :
				// post type
				$breadcrumb_title = ucfirst( get_post_type() ) . esc_html__( ' Details', 'sleeky' );
				$breadcrumb_class = get_post_type() . 'single-breadcrumb style-two';
			endif;
		elseif ( is_404() ) :
			$breadcrumb_title = esc_html__( 'Error Page', 'sleeky' );
			$breadcrumb_class = 'blog-breadcrumb';
		elseif ( is_search() ) :
			if ( have_posts() ) :
				$breadcrumb_title = esc_html__( 'Search Results for: ', 'sleeky' ) . get_search_query();
				$breadcrumb_class = 'blog-breadcrumb';
			else :
				$breadcrumb_title = esc_html__( 'Nothing Found', 'sleeky' );
				$breadcrumb_class = 'blog-breadcrumb';
			endif;
		elseif ( ! is_home() && ! is_front_page() && ! is_search() && ! is_404() ) :
			$breadcrumb_title = get_the_title();
			$breadcrumb_class = 'page-breadcrumb';
		endif;
		$breadcrumb_active_class = 'breadcrumb-not-active';
		if ( function_exists( 'bcn_display' ) ) :
			$breadcrumb_active_class = '';
		endif;
		?>
		<?php
		if ( is_page() ) {
			$sleeky_show_breadcrumb  = get_post_meta( get_the_ID(), 'sleeky_core_show_breadcrumb', true );
			$sleeky_page_title  = get_post_meta( get_the_ID(), 'sleeky_core_breadcrumb_title', true );
			$sleeky_page_sub_title  = get_post_meta( get_the_ID(), 'sleeky_core_breadcrumb_sub_title', true );
			$breadcrumb_extra_class  = get_post_meta( get_the_ID(), 'sleeky_core_breadcrumb_extra_class', true );
			if($sleeky_page_title != ""){
				$breadcrumb_title = $sleeky_page_title;
			} else{
				$breadcrumb_title = get_the_title();
			}
			
		} else {
			$sleeky_show_breadcrumb = 'on';
		}
		$header_menu_style            = sleeky_get_options( 'header_menu_style' );
		$breadcrumb_class_with_header = 'breadcrumb-class-with-header-one';
		if ( $header_menu_style == '2' ) :
			$breadcrumb_class_with_header = '';
		endif;
		?>
		<?php if ( $sleeky_show_breadcrumb != 'off' ) : 

			$sleeky_breadcrumb_style = get_post_meta( get_the_ID(), 'sleeky_core_breadcrumb_style', true );
			
			if ( ! $sleeky_breadcrumb_style ) {
				$sleeky_breadcrumb_style = sleeky_get_options( 'breadcrumb_style' );
			}

			if($sleeky_breadcrumb_style == '1'){
				$breadcrumb_class .= ' page-title centred';
			} elseif($sleeky_breadcrumb_style == '2'){
				$breadcrumb_class .= ' page-title style-two';
			}
			elseif($sleeky_breadcrumb_style == '3'){
				$breadcrumb_class .= ' page-title-three centred';
			} elseif($sleeky_breadcrumb_style == '4'){
				$breadcrumb_class .= ' page-title-three about-page centred';
				$breadcrumb_shape_img = get_post_meta(get_the_ID(), 'sleeky_core_breadcrumb_shape_img', array('size' => 'full'));
				
			} else{
				$breadcrumb_class .= ' page-title centred';
			}
			
			
			?>
			<?php
			if ( isset( $breadcrumb_title ) && ! empty( $breadcrumb_title ) ) :
				?>
				<!-- page-title-two -->
				<section class="<?php echo esc_attr( $breadcrumb_class . ' ' . $breadcrumb_active_class . ' ' . $breadcrumb_class_with_header . ' ' . $breadcrumb_extra_class ); ?>">
					<?php if($sleeky_breadcrumb_style == '4'){ ?>
					<div class="shape" style="background-image: url(<?php echo esc_url(wp_get_attachment_url($breadcrumb_shape_img)); ?>);"></div>
					<?php } ?>
					<div class="large-container">
						<?php if($sleeky_breadcrumb_style == '3' || $sleeky_breadcrumb_style == '4') { ?>
							<div class="inner-box">
							<h5><?php echo wp_kses( $sleeky_page_sub_title, 'code_contxt' ); ?></h5>
							<h1><?php echo wp_kses( $breadcrumb_title, 'code_contxt' ); ?></h1>
							<span class="animation_text_word_two"></span>
						</div>
					<?php } else { ?>
						<?php if(is_single()) { 
							if ( get_post_type( get_the_ID() ) == 'post' ) {
							?>
						<div class="content-box">
							<div class="text centred">
								<h1><?php echo wp_kses( $breadcrumb_title, 'code_contxt' ); ?></h1>
							</div>
							<?php if ( function_exists( 'bcn_display' ) ) : ?>
								<ul class="bread-crumb clearfix">
									<?php bcn_display(); ?>
								</ul>
							<?php endif;  ?>
						</div>
						<?php } } else{ ?>
						<div class="text">
							<h1><?php echo wp_kses( $breadcrumb_title, 'code_contxt' ); ?></h1>
							<?php if($sleeky_breadcrumb_style == '5'){ ?>
								<p><?php echo wp_kses_post( $sleeky_page_sub_title ); ?></p>
							<?php } else {
							if ( function_exists( 'bcn_display' ) ) : ?>
								<ul class="bread-crumb clearfix">
									<?php bcn_display(); ?>
								</ul>
							<?php endif; } ?>
						</div>
						<?php } } ?>
					</div>
				</section>
				<!-- page-title-two end -->
				<?php
			endif;
			?>
		<?php  endif; ?>
		<?php
	}

	/**
	 * autor box compatibility.
	 */
	public static function sleeky_authore_box() {
		$blog_authore_switch = sleeky_get_options( 'blog_authore_switch' );
		if ( $blog_authore_switch == 1 ) :
			global $post;
			$display_name     = get_the_author_meta( 'display_name', $post->post_author );
			$user_description = get_the_author_meta( 'user_description', $post->post_author );
			$designation      = get_the_author_meta( 'designation', $post->post_author );
			$facebook         = get_the_author_meta( 'facebook', $post->post_author );
			$twitter          = get_the_author_meta( 'twitter', $post->post_author );
			$youtube          = get_the_author_meta( 'youtube', $post->post_author );
			$instagram        = get_the_author_meta( 'instagram', $post->post_author );

			$user_avatar = get_avatar( $post->post_author, 80 );
			if ( isset( $display_name ) || isset( $user_description ) || isset( $user_avatar ) ) {
				?>
				<div class="author-box">
					<figure class="author-thumb"><?php echo wp_kses( $user_avatar, 'code_img' ); ?></figure>
					<h4><?php echo wp_kses_post( ucfirst( $display_name ) ); ?></h4>
					<span class="designation"><?php echo esc_html( $designation ); ?></span>
					<p><?php echo wp_kses_post( $user_description ); ?></p>
					<ul class="social-links clearfix">
						<?php if ( ! empty( $twitter ) ) { ?>
						<li><a href="<?php echo esc_url( $twitter ); ?>"><i class="fab fa-twitter"></i></a></li>
						<?php } ?>
						<?php if ( ! empty( $facebook ) ) { ?>
						<li><a href="<?php echo esc_url( $facebook ); ?>"><i class="fab fa-facebook-f"></i></a></li>
						<?php } ?>
						<?php if ( ! empty( $youtube ) ) { ?>
						<li><a href="<?php echo esc_url( $youtube ); ?>"><i class="fab fa-youtube"></i></a></li>
						<?php } ?>
						<?php if ( ! empty( $instagram ) ) { ?>
						<li><a href="<?php echo esc_url( $instagram ); ?>"><i class="fab fa-instagram"></i></a></li>
						<?php } ?>
					</ul>
				</div>
				<?php
			}
			endif;
	}

	/**
	 * sleeky compatibility.
	 */
	public static function code_contxt_allowed_html( $tags, $context ) {
		switch ( $context ) {
			case 'code_contxt':
				$tags = array(
					'iframe' => array(
						'allowfullscreen' => array(),
						'frameborder'     => array(),
						'height'          => array(),
						'width'           => array(),
						'src'             => array(),
						'class'           => array(),
					),
					'li'     => array(
						'class' => array(),
					),
					'h5'     => array(
						'class' => array(),
					),
					'span'   => array(
						'class' => array(),
					),
					'a'      => array(
						'href' => array(),
					),
					'i'      => array(
						'class' => array(),
					),
					'br'     => array(
						'class' => array(),
					),
					'select' => array(),
					'option' => array(),
					'p'      => array(),
					'b'      => array(),
					'em'     => array(),
					'strong' => array(),
					'del'    => array(),
					'ins'    => array(),
					'bdi'    => array(),
				);
				return $tags;
			case 'code_img':
				$tags = array(
					'img' => array(
						'class'  => array(),
						'height' => array(),
						'width'  => array(),
						'src'    => array(),
						'alt'    => array(),
					),
				);
				return $tags;
			default:
				return $tags;
		}
	}

	public static function sleeky_posts_nav() {
		$blog_authore_switch = sleeky_get_options( 'blog_post_nav_switch' );
		if ( $blog_authore_switch == 1 ) {
			$total = wp_count_posts()->publish;
			if ( $total > 1 ) {
				?>
			<div class="nav-btn clearfix">
				<?php
				the_post_navigation(
					array(
						'prev_text' => '<div class="single-btn prev-btn text-left pull-left">
						<div class="icon-box"><i class="fal fa-angle-left"></i></div><span>' . esc_html__( 'previous', 'sleeky' ) . '</span><h3>' . esc_html( '%title' ) . '</h3></div>',
						'next_text' => '<div class="single-btn next-btn text-right pull-right"><div class="icon-box"><i class="fal fa-angle-right"></i></div><span>' . esc_html__( 'next', 'sleeky' ) . '</span><h3>' . esc_html( '%title' ) . '
						</h3></div>',
					)
				);
				?>
			</div>
				<?php
			}
		}
	}


	public static function sleeky_related_posts() {

		$blog_related_post_switch = sleeky_get_options( 'blog_related_post_switch' );
		if ( $blog_related_post_switch == 1 ) {

			$catterms     = get_the_terms( get_the_ID(), 'category' );
			$catterm_list = wp_list_pluck( $catterms, 'slug' );

			$tagterms     = get_the_terms( get_the_ID(), 'post_tag' );
			$tagterm_list = wp_list_pluck( $tagterms, 'slug' );

			$get_posts = array();

				$rp_args = array(
					'post_type'      => array( 'post' ),
					'post_status'    => array( 'publish' ),
					'posts_per_page' => -1,
					'post__not_in'   => array( get_the_ID() ),
					'tax_query'      => array(
						'relation' => 'OR',
						array(
							'taxonomy' => 'category',
							'field'    => 'slug',
							'terms'    => $catterm_list,
							'operator' => 'NOT IN',
						),
						array(
							'taxonomy' => 'post_tag',
							'fields'   => 'slug',
							'terms'    => $tagterm_list,
							'operator' => 'NOT IN',
						),
					),
				);

				$related_posts_temp = new WP_Query( $rp_args );

				if ( $related_posts_temp->have_posts() ) {
					$get_posts = $related_posts_temp;
				}

				if ( $get_posts ) {
					?>
				<div class="related-post">
					<div class="group-title">
					<h2><?php esc_html_e( 'Related Posts', 'sleeky' ); ?></h2>
					</div>
					<div class="three-item-carousel">
						<div class="swiper-wrapper">
						<?php
						while ( $get_posts->have_posts() ) {
							$get_posts->the_post();
							global $post;
							?>
							<div class="swiper-slide">
								<div class="news-block-one">
									<div class="inner-box">
									<?php if ( has_post_thumbnail() ) { ?>
										<figure class="image-box"><a href="<?php esc_url( the_permalink() ); ?>"><?php the_post_thumbnail( 'sleeky-blog-list' ); ?></a></figure>
									<?php } ?>
										<div class="lower-content">
											<h3><a href="<?php esc_url( the_permalink() ); ?>"><?php the_title(); ?></a></h3>
											<ul class="post-info clearfix">
											<li><?php sleeky_category_list(); ?></li>
											<?php sleeky_posted_on(); ?>
											</ul>
											<?php
												if ( ! empty( get_the_excerpt() ) ) {
													if ( get_option( 'rss_use_excerpt' ) ) {
														the_excerpt();
													} else {
														the_excerpt();
													}
												}
												?>
										</div>
									</div>
								</div>
							</div>
						<?php } ?>  
						</div>
						<div class="swiper-nav">
							<div class="prev-btn"><i class="fal fa-angle-left"></i></div>
							<div class="next-btn"><i class="fal fa-angle-right"></i></div>
						</div>
					</div>
				</div>
				<?php
			} 
		}
	}
	public static function sleeky_related_products() {
		$blog_related_product_switch = sleeky_get_options( 'blog_related_product_switch' );
		if ( $blog_related_product_switch == 1 ) {

			$catterms     = get_the_terms( get_the_ID(), 'category' );
			$catterm_list = wp_list_pluck( $catterms, 'slug' );

			$tagterms     = get_the_terms( get_the_ID(), 'post_tag' );
			$tagterm_list = wp_list_pluck( $tagterms, 'slug' );

			$get_posts = array();

			$not___in   = array();
			$not___in[] = get_the_ID();

				$rp_args = array(
					'post_type'      => array( 'product' ),
					'post_status'    => array( 'publish' ),
					'posts_per_page' => -1,
					'exclude'        => get_the_ID(),
					'tax_query'      => array(
						'relation' => 'OR',
						array(
							'taxonomy' => 'category',
							'field'    => 'slug',
							'terms'    => $catterm_list,
							'operator' => 'NOT IN',
						),
						array(
							'taxonomy' => 'post_tag',
							'fields'   => 'slug',
							'terms'    => $tagterm_list,
							'operator' => 'NOT IN',
						),
					),
				);

				$related_posts_temp = new WP_Query( $rp_args );

				if ( $related_posts_temp->have_posts() ) {
					$get_posts = $related_posts_temp;
				}

				if ( $get_posts ) {
					?>
			<div class="related-product woocommerce">
				<div class="group-title">
				<h2><?php esc_html_e( 'Related Products', 'sleeky' ); ?></h2>
				</div>
				<div class="three-item-carousel">
					<div class="swiper-wrapper">
						<?php
							while ( $get_posts->have_posts() ) {
								$get_posts->the_post();
								global $post;
								wc_get_template_part( 'content', 'product-new' );
							}
							?>

					</div>
					<div class="swiper-nav">
						<div class="prev-btn"><i class="fal fa-angle-left"></i></div>
						<div class="next-btn"><i class="fal fa-angle-right"></i></div>
					</div>
				</div>
			</div>
				<?php
			}
			wp_reset_postdata();
		}
	}

	/**
	 * mobile menu compatibility.
	*/
	public static function sleeky_mobile_menu(){ 

		$sid_menu_info_title  		= sleeky_get_options( 'sid_menu_info_title' ); 
		$side_address  		  		= sleeky_get_options( 'side_address' ); 
		$side_number  		  		= sleeky_get_options( 'side_number' ); 
		$explode_number       		= explode( " ", $side_number ); 
		$implode_number       		= implode("",$explode_number);
		$side_email  		  		= sleeky_get_options( 'side_email' ); 
		$social_repeater_setting    = sleeky_get_options( 'social_repeater_setting' );
		$mobile_logo    			= sleeky_get_options( 'side_mobile_logo' );
		if(isset($mobile_logo['url'])){
			$mobile_logo =  $mobile_logo['url'];
		}
	?>

		<!-- Mobile Menu  -->
		<div class="mobile-menu">
            <div class="menu-backdrop"></div>
            <div class="close-btn"><i class="fas fa-times"></i></div>
            
            <nav class="menu-box">
                <div class="nav-logo">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
					<?php 
						if (!empty($mobile_logo)) { ?>
							<img src="<?php echo esc_url($mobile_logo);?>" alt="<?php esc_attr_e( 'Logo', 'sleeky' ); ?>">
						<?php 
						} else { ?>
							<img src="<?php echo esc_url( SLEEKY_IMG_URL . 'logo-2.png' ); ?>" alt="<?php esc_attr_e( 'Logo', 'sleeky' ); ?>">
						<?php } ?>
					</a>
				</div>
                <div class="menu-outer"><!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header--></div>
                <div class="contact-info">
				<?php if($side_address || $side_number || $side_email || $sid_menu_info_title){  ?>
					<?php if($sid_menu_info_title){ ?>
					<h4><?php echo esc_html($sid_menu_info_title);?></h4>
					<?php } 
					if($side_address || $side_number || $side_email){ 
					?>
					<ul>
						<li><?php echo wp_kses($side_address,'code_contxt');?></li>
						<li><a href="tel:<?php echo esc_attr($implode_number);?>"><?php echo wp_kses($side_number,'code_contxt');?></a></li>
						<li><a href="mailto:<?php echo esc_attr($side_email);?>"><?php echo wp_kses($side_email,'code_contxt');?></a></li>
					</ul>
					<?php } ?>
                </div>
				<?php } 
				if( !empty($social_repeater_setting) ) { ?>
                <div class="social-links">
                    <ul class="clearfix">
					<?php 
					foreach($social_repeater_setting as $value) { 
						$social_link =  $value['link_url'];
						$link_icon   =  $value['link_icon'];
						?>
						<li><a href="<?php echo esc_attr($social_link);?>"><span class="fab <?php echo esc_attr($link_icon);?>"></span></a></li>
					<?php } ?>
                    </ul>
                </div>
				<?php } ?>
            </nav>
        </div><!-- End Mobile Menu -->
	<?php 
	}
}
$sleeky_int = new Sleeky_Int();
