<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package sleeky
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function sleeky_body_classes( $classes ) {

	$header_style_meta = get_post_meta( get_the_ID(), 'sleeky_core_header_style', true );
	if ( $header_style_meta ) {
		$header_style = $header_style_meta;
	} else {
		$header_style = sleeky_get_options( 'header_style' );
	}

	$theme_base_css       = sleeky_get_options( 'theme_base_css' );
	$theme_base_css_class = 'base-theme';
	if ( $theme_base_css ) :
		$theme_base_css_class = '';
	endif;

	$demo_css = '';

	if ( $header_style == '3' ) {
		$demo_css = 'home-2';
	} elseif ( $header_style == '4' ) {
		$demo_css = 'home-3';
	} elseif ( $header_style == '5' ) {
		$demo_css = 'home-4';
	} elseif ( $header_style == '6' ) {
		$demo_css = 'home-4';
	}

	$classes[] = $demo_css;
	$classes[] = $theme_base_css_class;

	return $classes;
}
add_filter( 'body_class', 'sleeky_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function sleeky_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'sleeky_pingback_header' );

function code_contxt_allowed_html( $sleeky_tags, $sleeky_context ) {
	switch ( $sleeky_context ) {
		case 'code_contxt':
			$sleeky_tags = array(
				'div'    => array(
					'class' => array(),
				),
				'ul'     => array(
					'class' => array(),
				),
				'li'     => array(),
				'span'   => array(
					'class' => array(),
				),
				'a'      => array(
					'href'  => array(),
					'class' => array(),
				),
				'i'      => array(
					'class' => array(),
				),
				'p'      => array(),
				'em'     => array(),
				'br'     => array(),
				'strong' => array(),
				'h1'     => array(),
				'h2'     => array(),
				'h3'     => array(),
				'h4'     => array(),
				'h5'     => array(),
				'h6'     => array(),
				'del'    => array(),
				'ins'    => array(),
			);
			return $sleeky_tags;
		case 'sleeky_img':
			$sleeky_tags = array(
				'img' => array(
					'class'  => array(),
					'height' => array(),
					'width'  => array(),
					'src'    => array(),
					'alt'    => array(),
				),
			);
			return $sleeky_tags;
		default:
			return $sleeky_tags;

	}
}

add_filter( 'wp_kses_allowed_html', 'code_contxt_allowed_html', 10, 2 );