<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package sleeky
 */

if ( ! function_exists( 'sleeky_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function sleeky_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( ' %s', 'post date', 'sleeky' ),
			'' . $time_string . ''
		);

		echo '<li>' . $posted_on . '</li>';

	}
endif;

if ( ! function_exists( 'sleeky_category_list' ) ) :
	function sleeky_category_list() {
		if ( 'post' === get_post_type() ) {
			$category_list = get_the_category_list( esc_html__( ', ', 'sleeky' ) );
			if ( $category_list ) {
				printf( $category_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'sleeky_category_only' ) ) :
	function sleeky_category_only() {
		if ( 'post' === get_post_type() ) {
			$category = get_the_category();
			if ( $category[0] ) {
				echo '<li><a href="' . get_category_link( $category[0]->term_id ) . '">' . $category[0]->cat_name . '</a></li>';
			}
		}
	}
endif;

if ( ! function_exists( 'sleeky_tag_list' ) ) :
	function sleeky_tag_list() {
		if ( 'post' === get_post_type() ) {
			$tag_list = get_the_tag_list( '<li>', esc_html_x( ' ', 'list item separator', 'sleeky' ) );
			if ( $tag_list ) {
				printf( $tag_list ); // WPCS: XSS OK.
			}
		}
	}
endif;


if ( ! function_exists( 'sleeky_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function sleeky_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( '%s', 'post author', 'sleeky' ),
			'<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"><span>' . esc_html( get_the_author() ) . '</span></a>'
		);
		echo esc_html__( 'By', 'sleeky' ) . ' ' . $byline;

	}
endif;

if ( ! function_exists( 'sleeky_posted_by_auth' ) ) :
	/**
	 * Prints HTML with meta information for the current author by.
	 */
	function sleeky_posted_by_auth() {
		global $post;
		$author_id = $post->post_author;
		$byline    = sprintf(
			/* translators: %s: post author. */
			esc_html( get_the_author_meta( 'display_name', $author_id ) )
		);
		echo esc_html__( 'By', 'sleeky' ) . '<span>' . $byline . '</span>';
	}
endif;


if ( ! function_exists( 'sleeky_comments_count' ) ) :
	function sleeky_comments_count() {
		if ( get_comments_number( get_the_ID() ) == 0 ) {
			$comments_count = get_comments_number( get_the_ID() ) . esc_html__( ' Comments', 'sleeky' );
		} elseif ( get_comments_number( get_the_ID() ) > 1 ) {
			$comments_count = get_comments_number( get_the_ID() ) . esc_html__( ' Comments', 'sleeky' );
		} else {
			$comments_count = get_comments_number( get_the_ID() ) . esc_html__( ' Comment', 'sleeky' );
		}
		echo sprintf( esc_html( '%s' ), $comments_count );
	}
endif;


if ( ! function_exists( 'sleeky_comments' ) ) {
	function sleeky_comments( $comment, $args, $depth ) {
		extract( $args, EXTR_SKIP );

		$class = '';
		if ( $depth > 1 ) {
			$class = '';
		}
		if ( $depth == 1 ) {
			$child_html_el     = '<ul><li>';
			$child_html_end_el = '</li></ul>';
		}

		if ( $depth >= 2 ) {
			$child_html_el     = '<li>';
			$child_html_end_el = '</li>';
		}
		$comment_class_ping = 'yes-ping';
		if ( $comment->comment_type != 'trackback' && $comment->comment_type != 'pingback' ) :
			$comment_class_ping = '';
		endif;
		?>
			<div class="comment single-comment <?php echo esc_attr( $comment_class_ping ); ?>" id="comment-<?php comment_ID(); ?>">
				<?php if ( $comment->comment_type != 'trackback' && $comment->comment_type != 'pingback' ) { ?>
				<figure class="thumb-box">
					<?php print get_avatar( $comment, 70, null, null, array( 'class' => array() ) ); ?>
				</figure>
				<?php } ?>
				<div class="comment-inner">
					<div class="comment-info clearfix">
						<h5><?php echo get_comment_author_link(); ?></h5>
						<span class="post-time"><?php echo get_the_date(); ?></span>
					</div>
					<?php comment_text(); ?>
					<?php
						$replyBtn = 'reply-btn';
						echo preg_replace(
							'/comment-reply-link/',
							'comment-reply-link ' . $replyBtn,
							get_comment_reply_link(
								array_merge(
									$args,
									array(
										'reply_text' => esc_html__( 'Reply', 'sleeky' ),
										'depth'      => $depth,
										'max_depth'  => $args['max_depth'],
									)
								)
							),
							1
						);
					?>
				</div>
		<?php
	}
}
